/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2009 Jaroslav Tulach
 */

package cz.xelfi.quoridor.freemarkerdor;

import com.sun.jersey.api.client.Client;
import com.sun.jersey.api.client.WebResource;
import com.sun.jersey.core.header.MediaTypes;
import java.io.File;
import java.io.IOException;
import java.net.URI;
import java.util.Locale;
import java.util.concurrent.Callable;
import javax.ws.rs.core.Cookie;
import org.junit.After;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;

/**
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
public class UITest extends Object {
    private File dir;
    private Callable<Void> stop;
    private WebResource webResource;

    public UITest() throws Exception {
    }

    @BeforeClass
    public static void localeEnglish() {
        Locale.setDefault(Locale.ENGLISH);
    }

    @Before
    public void setUp() throws Exception {
        dir = File.createTempFile("quoridor", ".dir");
        dir.delete();
        System.setProperty("quoridor.dir", dir.getPath());
        stop = UI.startServers(9991);

        Client client = new Client();
        webResource = client.resource(new URI("http://localhost:9991/"));
    }

    @After
    public void tearDown() throws Exception {
        deleteRec(dir);
        if (stop != null) {
            stop.call();
        }
    }

    static void deleteRec(File dir) throws IOException {
        if (dir == null) {
            return;
        }
        File[] arr = dir.listFiles();
        if (arr != null) {
            for (File f : arr) {
                deleteRec(f);
            }
        }
        dir.delete();
    }

    /**
     * Test if a WADL document is available at the relative path
     * "application.wadl".
     */
    @Test public void testApplicationWadl() {
        String serviceWadl = webResource.path("application.wadl").
                accept(MediaTypes.WADL).get(String.class);
        assertTrue(serviceWadl.length() > 0);
    }

    @Test public void testGetIndexPage() throws Exception {
        String res = webResource.accept("text/html").get(String.class);
        if (res.indexOf("Quoridor") == -1) {
            fail("Wrong index.html:\n" + res);
        }
        if (res.indexOf("Login") == -1) {
            fail("Wrong index.html:\n" + res);
        }
        if (res.indexOf("action=\"login\"") == -1) {
            fail("Wrong index.html:\n" + res);
        }
        if (res.toLowerCase().indexOf("error") != -1) {
            fail("There was an error:\n" + res);
        }
        res = webResource.cookie(Cookie.valueOf("login=jarda")).accept("text/html").get(String.class);
        if (res.indexOf("action=\"games/create\"") == -1) {
            fail(res);
        }
    }

}
